;; Generated package description from swiper.el  -*- no-byte-compile: t -*-
(define-package "swiper" "0.15.1.0.20260212.144752" "Isearch with an overview.  Oh, man!" '((emacs "24.5") (ivy "0.15.1")) :commit "cc0ae78e4fb3657bb29a07265ccba5e7b1df70c4" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("matching") :url "https://github.com/abo-abo/swiper")
